@@ -19,7 +19,7 @@ import sys
 from types import MappingProxyType
 from typing import Any, Final, NamedTuple, Required, TypedDict
 
-VERSION: Final = "2025.11.17"
+VERSION: Final = "2025.11.22"
 
 # Detect test speedup mode via environment
 _TEST_SPEEDUP: Final = (
@@ -82,9 +82,6 @@ RENAME_SYSVAR_BY_NAME: Final[Mapping[str, str]] = MappingProxyType(
     }
 )
 
-# Deprecated alias (use ALWAYS_ENABLE_SYSVARS_BY_ID). Kept for backward compatibility.
-SYSVAR_ENABLE_DEFAULT: Final[frozenset[str]] = ALWAYS_ENABLE_SYSVARS_BY_ID
-
 ADDRESS_SEPARATOR: Final = ":"
 BLOCK_LOG_TIMEOUT: Final = 60
 CONTENT_PATH: Final = "cache"
@@ -1265,7 +1262,9 @@ CLIMATE_SCHEDULE_SLOT_IN_RANGE: Final = range(1, 14)
 CLIMATE_SCHEDULE_SLOT_RANGE: Final = range(1, 13)
 CLIMATE_SCHEDULE_TIME_RANGE: Final = range(1441)
 CLIMATE_SIMPLE_WEEKDAY_LIST = list[dict[ScheduleSlotType, str | float]]
-CLIMATE_SIMPLE_PROFILE_DICT = dict[WeekdayStr, CLIMATE_SIMPLE_WEEKDAY_LIST]
+CLIMATE_SIMPLE_WEEKDAY_DATA = tuple[float, CLIMATE_SIMPLE_WEEKDAY_LIST]
+CLIMATE_SIMPLE_PROFILE_DICT = dict[WeekdayStr, CLIMATE_SIMPLE_WEEKDAY_DATA]
+CLIMATE_SIMPLE_SCHEDULE_DICT = dict[ScheduleProfile, CLIMATE_SIMPLE_PROFILE_DICT]
 DEFAULT_CLIMATE_FILL_TEMPERATURE: Final = 18.0
 DEFAULT_SCHEDULE_GROUP = dict[ScheduleField, Any]
 DEFAULT_SCHEDULE_DICT = dict[int, DEFAULT_SCHEDULE_GROUP]
