@@ -63,7 +63,10 @@ class CalculatedDataPoint[ParameterT: ParamType](BaseDataPoint):
         """Initialize the data point."""
         self._unregister_callbacks: list[UnregisterCallback] = []
         unique_id = generate_unique_id(
-            central=channel.central, address=channel.address, parameter=self._calculated_parameter, prefix="calculated"
+            config_provider=channel.device.config_provider,
+            address=channel.address,
+            parameter=self._calculated_parameter,
+            prefix="calculated",
         )
         super().__init__(
             channel=channel,
@@ -148,8 +151,8 @@ class CalculatedDataPoint[ParameterT: ParamType](BaseDataPoint):
         return all(dp.is_valid for dp in self._relevant_data_points)
 
     @property
-    def is_writeable(self) -> bool:
-        """Return, if data_point is writeable."""
+    def is_writable(self) -> bool:
+        """Return, if data_point is writable."""
         return bool(self._operations & Operations.WRITE)
 
     @property
@@ -329,5 +332,3 @@ class CalculatedDataPoint[ParameterT: ParamType](BaseDataPoint):
         for unregister in self._unregister_callbacks:
             if unregister is not None:
                 unregister()
-
-        super()._unregister_data_point_updated_callback(cb=cb, custom_id=custom_id)
