@@ -16,8 +16,10 @@ from aiohomematic.const import (
     BIDCOS_DEVICE_CHANNEL_DUMMY,
     CLIMATE_PROFILE_DICT,
     CLIMATE_SIMPLE_PROFILE_DICT,
-    CLIMATE_SIMPLE_WEEKDAY_LIST,
+    CLIMATE_SIMPLE_SCHEDULE_DICT,
+    CLIMATE_SIMPLE_WEEKDAY_DATA,
     CLIMATE_WEEKDAY_DICT,
+    DEFAULT_CLIMATE_FILL_TEMPERATURE,
     DataPointCategory,
     DeviceProfile,
     Field,
@@ -208,6 +210,13 @@ class BaseCustomDpClimate(CustomDataPoint):
         """Return the number of supported profiles."""
         return 0
 
+    @property
+    def simple_schedule(self) -> CLIMATE_SIMPLE_SCHEDULE_DICT:
+        """Return cached simple schedule entries from device week profile."""
+        if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
+            return self._device.week_profile.simple_schedule
+        return {}
+
     @property
     def supports_profiles(self) -> bool:
         """Flag if climate supports profiles."""
@@ -305,7 +314,7 @@ class BaseCustomDpClimate(CustomDataPoint):
     ) -> None:
         """Copy schedule profile to target device (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            await self._device.week_profile.copy_schedule_profile(
+            await self._device.week_profile.copy_profile(
                 source_profile=source_profile,
                 target_profile=target_profile,
                 target_climate_data_point=target_climate_data_point,
@@ -327,18 +336,43 @@ class BaseCustomDpClimate(CustomDataPoint):
     async def get_schedule_profile(self, *, profile: ScheduleProfile, force_load: bool = False) -> CLIMATE_PROFILE_DICT:
         """Return a schedule by climate profile (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            return await self._device.week_profile.get_schedule_profile(profile=profile, force_load=force_load)
+            return await self._device.week_profile.get_profile(profile=profile, force_load=force_load)
         return {}
 
     @inspector
-    async def get_schedule_profile_weekday(
+    async def get_schedule_simple_profile(
+        self, *, profile: ScheduleProfile, force_load: bool = False
+    ) -> CLIMATE_SIMPLE_PROFILE_DICT:
+        """Return a simple schedule by climate profile (delegates to week profile)."""
+        if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
+            return await self._device.week_profile.get_simple_profile(profile=profile, force_load=force_load)
+        return {}
+
+    @inspector
+    async def get_schedule_simple_schedule(self, *, force_load: bool = False) -> CLIMATE_SIMPLE_SCHEDULE_DICT:
+        """Return the complete simple schedule dictionary (delegates to week profile)."""
+        if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
+            return await self._device.week_profile.get_simple_schedule(force_load=force_load)
+        return {}
+
+    @inspector
+    async def get_schedule_simple_weekday(
+        self, *, profile: ScheduleProfile, weekday: WeekdayStr, force_load: bool = False
+    ) -> CLIMATE_SIMPLE_WEEKDAY_DATA:
+        """Return a simple schedule by climate profile and weekday (delegates to week profile)."""
+        if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
+            return await self._device.week_profile.get_simple_weekday(
+                profile=profile, weekday=weekday, force_load=force_load
+            )
+        return DEFAULT_CLIMATE_FILL_TEMPERATURE, []
+
+    @inspector
+    async def get_schedule_weekday(
         self, *, profile: ScheduleProfile, weekday: WeekdayStr, force_load: bool = False
     ) -> CLIMATE_WEEKDAY_DICT:
         """Return a schedule by climate profile and weekday (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            return await self._device.week_profile.get_schedule_profile_weekday(
-                profile=profile, weekday=weekday, force_load=force_load
-            )
+            return await self._device.week_profile.get_weekday(profile=profile, weekday=weekday, force_load=force_load)
         return {}
 
     def is_state_change(self, **kwargs: Any) -> bool:
@@ -367,12 +401,12 @@ class BaseCustomDpClimate(CustomDataPoint):
     ) -> None:
         """Set a profile to device (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            await self._device.week_profile.set_schedule_profile(
+            await self._device.week_profile.set_profile(
                 profile=profile, profile_data=profile_data, do_validate=do_validate
             )
 
     @inspector
-    async def set_schedule_profile_weekday(
+    async def set_schedule_weekday(
         self,
         *,
         profile: ScheduleProfile,
@@ -382,40 +416,41 @@ class BaseCustomDpClimate(CustomDataPoint):
     ) -> None:
         """Store a profile weekday to device (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            await self._device.week_profile.set_schedule_profile_weekday(
+            await self._device.week_profile.set_weekday(
                 profile=profile, weekday=weekday, weekday_data=weekday_data, do_validate=do_validate
             )
 
+    @inspector
+    async def set_simple_schedule(self, *, simple_schedule_data: CLIMATE_SIMPLE_SCHEDULE_DICT) -> None:
+        """Set the complete simple schedule dictionary to device (delegates to week profile)."""
+        if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
+            await self._device.week_profile.set_simple_schedule(simple_schedule_data=simple_schedule_data)
+
     @inspector
     async def set_simple_schedule_profile(
         self,
         *,
         profile: ScheduleProfile,
-        base_temperature: float,
         simple_profile_data: CLIMATE_SIMPLE_PROFILE_DICT,
     ) -> None:
         """Set a profile to device using simple format (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            await self._device.week_profile.set_simple_schedule_profile(
-                profile=profile, base_temperature=base_temperature, simple_profile_data=simple_profile_data
-            )
+            await self._device.week_profile.set_simple_profile(profile=profile, simple_profile_data=simple_profile_data)
 
     @inspector
-    async def set_simple_schedule_profile_weekday(
+    async def set_simple_schedule_weekday(
         self,
         *,
         profile: ScheduleProfile,
         weekday: WeekdayStr,
-        base_temperature: float,
-        simple_weekday_list: CLIMATE_SIMPLE_WEEKDAY_LIST,
+        simple_weekday_data: CLIMATE_SIMPLE_WEEKDAY_DATA,
     ) -> None:
         """Store a simple weekday profile to device (delegates to week profile)."""
         if self._device.week_profile and isinstance(self._device.week_profile, wp.ClimeateWeekProfile):
-            await self._device.week_profile.set_simple_schedule_profile_weekday(
+            await self._device.week_profile.set_simple_weekday(
                 profile=profile,
                 weekday=weekday,
-                base_temperature=base_temperature,
-                simple_weekday_list=simple_weekday_list,
+                simple_weekday_data=simple_weekday_data,
             )
 
     @bind_collector
@@ -488,7 +523,10 @@ class BaseCustomDpClimate(CustomDataPoint):
             )
         )
 
-        if OptionalSettings.ENABLE_LINKED_ENTITY_CLIMATE_ACTIVITY not in self._device.central.config.optional_settings:
+        if (
+            OptionalSettings.ENABLE_LINKED_ENTITY_CLIMATE_ACTIVITY
+            not in self._device.config_provider.config.optional_settings
+        ):
             return
 
         for ch in self._device.channels.values():
