@@ -1,23 +1,24 @@
 # SPDX-License-Identifier: MIT
-# Copyright (c) 2021-2025 Daniel Perna, SukramJ
+# Copyright (c) 2021-2025
 """Support classes used by aiohomematic custom data points."""
 
 from __future__ import annotations
 
-from collections.abc import Callable, Mapping
+from collections.abc import Mapping
 from dataclasses import dataclass
 
-from aiohomematic.const import Parameter
-from aiohomematic.model.custom.const import Field
+from aiohomematic.const import Field, Parameter
+from aiohomematic.type_aliases import CustomDataPointFactory
 
 
 @dataclass(frozen=True, kw_only=True, slots=True)
 class CustomConfig:
     """Data for custom data_point creation."""
 
-    make_ce_func: Callable
+    make_ce_func: CustomDataPointFactory
     channels: tuple[int | None, ...] = (1,)
     extended: ExtendedConfig | None = None
+    schedule_channel_no: int | None = None
 
 
 @dataclass(frozen=True, kw_only=True, slots=True)
