@@ -25,19 +25,19 @@ parameter values across all supported devices.
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from collections import defaultdict
 from collections.abc import Callable, Mapping
 from contextvars import Token
 from datetime import datetime, timedelta
-from functools import partial, wraps
+from functools import wraps
 from inspect import getfullargspec
 import logging
 from typing import Any, Final, TypeAlias, TypeVar, cast, overload
 
 import voluptuous as vol
 
-from aiohomematic import central as hmcu, client as hmcl, i18n, support as hms, validator as val
+from aiohomematic import client as hmcl, i18n, support as hms, validator as val
 from aiohomematic.async_support import loop_check
+from aiohomematic.central.event_bus import DataPointUpdatedCallbackEvent, DeviceRemovedEvent
 from aiohomematic.const import (
     DEFAULT_MULTIPLIER,
     DP_KEY_VALUE,
@@ -65,10 +65,17 @@ from aiohomematic.const import (
 from aiohomematic.context import IN_SERVICE_VAR
 from aiohomematic.decorators import get_service_calls
 from aiohomematic.exceptions import AioHomematicException, BaseHomematicException
+from aiohomematic.interfaces import (
+    CentralInfo,
+    EventBusProvider,
+    ParameterVisibilityProvider,
+    ParamsetDescriptionProvider,
+    TaskScheduler,
+)
 from aiohomematic.model import device as hmd
 from aiohomematic.model.support import DataPointNameData, DataPointPathData, PathData, convert_value, generate_unique_id
 from aiohomematic.property_decorators import config_property, hm_property, state_property
-from aiohomematic.support import LogContextMixin, PayloadMixin, extract_exc_args, log_boundary_error
+from aiohomematic.support import LogContextMixin, PayloadMixin, log_boundary_error
 from aiohomematic.type_aliases import (
     CallableAny,
     DataPointUpdatedCallback,
@@ -140,17 +147,21 @@ class CallbackDataPoint(ABC, LogContextMixin):
 
     __slots__ = (
         "_cached_enabled_default",
-        "_cached_service_methods",
         "_cached_service_method_names",
-        "_central",
+        "_cached_service_methods",
+        "_central_info",
         "_custom_id",
-        "_data_point_updated_callbacks",
-        "_device_removed_callbacks",
         "_emitted_event_at",
+        "_event_bus_provider",
         "_modified_at",
+        "_parameter_visibility_provider",
+        "_paramset_description_provider",
         "_path_data",
         "_refreshed_at",
+        "_registered_custom_ids",
         "_signature",
+        "_subscription_counts",
+        "_task_scheduler",
         "_temporary_modified_at",
         "_temporary_refreshed_at",
         "_unique_id",
@@ -158,12 +169,25 @@ class CallbackDataPoint(ABC, LogContextMixin):
 
     _category = DataPointCategory.UNDEFINED
 
-    def __init__(self, *, central: hmcu.CentralUnit, unique_id: str) -> None:
+    def __init__(
+        self,
+        *,
+        unique_id: str,
+        central_info: CentralInfo,
+        event_bus_provider: EventBusProvider,
+        task_scheduler: TaskScheduler,
+        paramset_description_provider: ParamsetDescriptionProvider,
+        parameter_visibility_provider: ParameterVisibilityProvider,
+    ) -> None:
         """Init the callback data_point."""
-        self._central: Final = central
+        self._central_info: Final = central_info
+        self._event_bus_provider: Final = event_bus_provider
+        self._task_scheduler: Final = task_scheduler
+        self._paramset_description_provider: Final = paramset_description_provider
+        self._parameter_visibility_provider: Final = parameter_visibility_provider
         self._unique_id: Final = unique_id
-        self._data_point_updated_callbacks: dict[str, set[DataPointUpdatedCallback]] = defaultdict(set)
-        self._device_removed_callbacks: list[DeviceRemovedCallback] = []
+        self._registered_custom_ids: set[str] = set()
+        self._subscription_counts: dict[str, int] = {}
         self._custom_id: str | None = None
         self._path_data = self._get_path_data()
         self._emitted_event_at: datetime = INIT_DATETIME
@@ -182,21 +206,53 @@ class CallbackDataPoint(ABC, LogContextMixin):
         """Return, the default category of the data_point."""
         return cls._category
 
+    @property
+    def _event_emitter(self) -> Any:
+        """
+        Return the event emitter.
+
+        This property documents that components only depend on event emission
+        functionality from CentralUnit, not the full API.
+        Returns event bus provider (which implements EventEmitter protocol).
+
+        Type: EventEmitter protocol (from model.interfaces)
+        """
+        return self._event_bus_provider
+
+    @property
+    def _paramset_provider(self) -> Any:
+        """
+        Return the paramset description provider.
+
+        This property documents that CallbackDataPoint only depends on
+        paramset_descriptions functionality from CentralUnit, not the full API.
+
+        Type: ParamsetDescriptionProvider protocol (from model.interfaces)
+        """
+        return self._paramset_description_provider
+
     @property
     def _should_emit_data_point_updated_callback(self) -> bool:
         """Check if a data point has been updated or refreshed."""
         return True
 
+    @property
+    def _visibility_provider(self) -> Any:
+        """
+        Return the parameter visibility provider.
+
+        This property documents that CallbackDataPoint only depends on
+        parameter_visibility functionality from CentralUnit, not the full API.
+
+        Type: ParameterVisibilityProvider protocol (from model.interfaces)
+        """
+        return self._parameter_visibility_provider
+
     @property
     def category(self) -> DataPointCategory:
         """Return, the category of the data point."""
         return self._category
 
-    @property
-    def central(self) -> hmcu.CentralUnit:
-        """Return the central unit."""
-        return self._central
-
     @property
     def custom_id(self) -> str | None:
         """Return the custom id."""
@@ -323,26 +379,55 @@ class CallbackDataPoint(ABC, LogContextMixin):
         if not self._should_emit_data_point_updated_callback:
             return
         self._emitted_event_at = datetime.now()
-        for custom_id, callback_handlers in self._data_point_updated_callbacks.items():
-            for callback_handler in callback_handlers:
-                try:
-                    # Add the data_point reference once to kwargs to avoid per-callback writes.
-                    kwargs[KWARGS_ARG_DATA_POINT] = self
-                    kwargs[KWARGS_ARG_CUSTOM_ID] = custom_id
-                    callback_handler(**kwargs)
-                except Exception as exc:
-                    _LOGGER.error(  # i18n-log: ignore
-                        "EMIT_DATA_POINT_UPDATED_EVENT failed: %s", extract_exc_args(exc=exc)
+
+        # Add the data_point reference to kwargs once
+        event_kwargs = {**kwargs, KWARGS_ARG_DATA_POINT: self}
+
+        # Publish events to EventBus asynchronously - one event per registered custom_id
+        for custom_id in self._registered_custom_ids:
+            # Add custom_id to kwargs for this specific event
+            custom_kwargs = {**event_kwargs, KWARGS_ARG_CUSTOM_ID: custom_id}
+
+            async def _publish(
+                cid: str,
+                ckw: dict[str, Any],
+            ) -> None:  # noqa: E731
+                """Publish callback event with custom id."""
+                await self._event_bus_provider.event_bus.publish(
+                    event=DataPointUpdatedCallbackEvent(
+                        timestamp=datetime.now(),
+                        unique_id=self._unique_id,
+                        custom_id=cid,
+                        kwargs=ckw,
                     )
+                )
+
+            async def _publish_wrapper(cid: str = custom_id, ckw: dict[str, Any] = custom_kwargs) -> None:  # noqa: E731
+                """Call publish with custom id and kwargs."""
+                await _publish(cid, ckw)
+
+            self._task_scheduler.create_task(
+                target=_publish_wrapper,
+                name=f"emit-callback-event-{self._unique_id}-{custom_id}",
+            )
 
     @loop_check
     def emit_device_removed_event(self) -> None:
         """Do what is needed when the data_point has been removed."""
-        for callback_handler in self._device_removed_callbacks:
-            try:
-                callback_handler()
-            except Exception as exc:
-                _LOGGER.error("EMIT_DEVICE_REMOVED_EVENT failed: %s", extract_exc_args(exc=exc))  # i18n-log: ignore
+
+        # Publish to EventBus asynchronously
+        async def _publish_device_removed() -> None:
+            await self._event_bus_provider.event_bus.publish(
+                event=DeviceRemovedEvent(
+                    timestamp=datetime.now(),
+                    unique_id=self._unique_id,
+                )
+            )
+
+        self._task_scheduler.create_task(
+            target=_publish_device_removed,
+            name=f"emit-device-removed-{self._unique_id}",
+        )
 
     async def finalize_init(self) -> None:
         """Finalize the data point init action after model setup."""
@@ -362,17 +447,50 @@ class CallbackDataPoint(ABC, LogContextMixin):
                 )
             self._custom_id = custom_id
 
-        if callable(cb) and cb not in self._data_point_updated_callbacks[custom_id]:
-            self._data_point_updated_callbacks[custom_id].add(cb)
-            return partial(self._unregister_data_point_updated_callback, cb=cb, custom_id=custom_id)
-        return None
+        # Track registration for emit method
+        self._registered_custom_ids.add(custom_id)
+
+        # Create adapter that filters for this data point's events with matching custom_id
+        def event_handler(event: DataPointUpdatedCallbackEvent) -> None:
+            if event.unique_id == self._unique_id and event.custom_id == custom_id:
+                cb(**event.kwargs)
+
+        unsubscribe = self._event_bus_provider.event_bus.subscribe(
+            event_type=DataPointUpdatedCallbackEvent,
+            handler=event_handler,
+        )
+
+        # Track subscription count per custom_id for proper cleanup
+        current_count = self._subscription_counts.get(custom_id, 0)
+        self._subscription_counts[custom_id] = current_count + 1
+
+        # Wrap unsubscribe to also remove from tracking when last subscription is removed
+        def wrapped_unsubscribe() -> None:
+            unsubscribe()
+            # Decrement subscription count
+            count = self._subscription_counts.get(custom_id, 1)
+            count -= 1
+            if count <= 0:
+                # Last subscription for this custom_id, remove from tracking
+                self._registered_custom_ids.discard(custom_id)
+                self._subscription_counts.pop(custom_id, None)
+            else:
+                self._subscription_counts[custom_id] = count
+
+        return wrapped_unsubscribe
 
     def register_device_removed_callback(self, *, cb: DeviceRemovedCallback) -> UnregisterCallback:
         """Register the device removed callback."""
-        if callable(cb) and cb not in self._device_removed_callbacks:
-            self._device_removed_callbacks.append(cb)
-            return partial(self._unregister_device_removed_callback, cb=cb)
-        return None
+
+        # Create adapter that filters for this data point's events
+        def event_handler(event: DeviceRemovedEvent) -> None:
+            if event.unique_id == self._unique_id:
+                cb()
+
+        return self._event_bus_provider.event_bus.subscribe(
+            event_type=DeviceRemovedEvent,
+            handler=event_handler,
+        )
 
     def register_internal_data_point_updated_callback(self, *, cb: DataPointUpdatedCallback) -> UnregisterCallback:
         """Register internal data_point updated callback."""
@@ -409,18 +527,6 @@ class CallbackDataPoint(ABC, LogContextMixin):
         """Set temporary_refreshed_at to current datetime."""
         self._temporary_refreshed_at = refreshed_at
 
-    def _unregister_data_point_updated_callback(self, *, cb: DataPointUpdatedCallback, custom_id: str) -> None:
-        """Unregister data_point updated callback."""
-        if cb in self._data_point_updated_callbacks[custom_id]:
-            self._data_point_updated_callbacks[custom_id].remove(cb)
-        if self.custom_id == custom_id:
-            self._custom_id = None
-
-    def _unregister_device_removed_callback(self, *, cb: DeviceRemovedCallback) -> None:
-        """Unregister the device removed callback."""
-        if cb in self._device_removed_callbacks:
-            self._device_removed_callbacks.remove(cb)
-
 
 class BaseDataPoint(CallbackDataPoint, PayloadMixin):
     """Base class for regular data point."""
@@ -451,7 +557,14 @@ class BaseDataPoint(CallbackDataPoint, PayloadMixin):
         PayloadMixin.__init__(self)
         self._channel: Final[hmd.Channel] = channel
         self._device: Final[hmd.Device] = channel.device
-        super().__init__(central=channel.central, unique_id=unique_id)
+        super().__init__(
+            unique_id=unique_id,
+            central_info=channel.device.central_info,
+            event_bus_provider=channel.device.event_bus_provider,
+            task_scheduler=channel.device.task_scheduler,
+            paramset_description_provider=channel.device.paramset_description_provider,
+            parameter_visibility_provider=channel.device.parameter_visibility_provider,
+        )
         self._is_in_multiple_channels: Final = is_in_multiple_channels
         self._client: Final[hmcl.Client] = channel.device.client
         self._forced_usage: DataPointUsage | None = None
@@ -616,16 +729,16 @@ class BaseParameterDataPoint[
         super().__init__(
             channel=channel,
             unique_id=generate_unique_id(
-                central=channel.central,
+                config_provider=channel.device.config_provider,
                 address=channel.address,
                 parameter=parameter,
                 prefix=unique_id_prefix,
             ),
-            is_in_multiple_channels=channel.device.central.paramset_descriptions.is_in_multiple_channels(
+            is_in_multiple_channels=channel.device.paramset_description_provider.is_in_multiple_channels(
                 channel_address=channel.address, parameter=parameter
             ),
         )
-        self._is_un_ignored: Final[bool] = self._central.parameter_visibility.parameter_is_un_ignored(
+        self._is_un_ignored: Final[bool] = self._visibility_provider.parameter_is_un_ignored(
             channel=channel,
             paramset_key=self._paramset_key,
             parameter=self._parameter,
@@ -685,8 +798,8 @@ class BaseParameterDataPoint[
         return self._raw_unit != self._unit
 
     @property
-    def is_writeable(self) -> bool:
-        """Return, if data_point is writeable."""
+    def is_writable(self) -> bool:
+        """Return, if data_point is writable."""
         return False if self._is_forced_sensor else bool(self._operations & Operations.WRITE)
 
     @property
@@ -881,7 +994,7 @@ class BaseParameterDataPoint[
 
     def update_parameter_data(self) -> None:
         """Update parameter data."""
-        if parameter_data := self._central.paramset_descriptions.get_parameter_data(
+        if parameter_data := self._paramset_provider.get_parameter_data(
             interface_id=self._device.interface_id,
             channel_address=self._channel.address,
             paramset_key=self._paramset_key,
@@ -1015,7 +1128,6 @@ class CallParameterCollector:
     """Create a Paramset based on given generic data point."""
 
     __slots__ = (
-        "_central",
         "_client",
         "_paramsets",
     )
@@ -1023,7 +1135,6 @@ class CallParameterCollector:
     def __init__(self, *, client: hmcl.Client) -> None:
         """Init the generator."""
         self._client: Final = client
-        self._central: Final = client.central
         # {"VALUES": {50: {"00021BE9957782:3": {"STATE3": True}}}}
         self._paramsets: Final[dict[ParamsetKey, dict[int, dict[str, dict[str, Any]]]]] = {}
 
