@@ -25,7 +25,6 @@ from __future__ import annotations
 import asyncio
 from collections.abc import Mapping
 from datetime import datetime
-from functools import partial
 import logging
 import os
 import random
@@ -33,8 +32,9 @@ from typing import Any, Final, cast
 
 import orjson
 
-from aiohomematic import central as hmcu, client as hmcl, i18n
+from aiohomematic import client as hmcl, i18n
 from aiohomematic.async_support import loop_check
+from aiohomematic.central.event_bus import DeviceUpdatedEvent, FirmwareUpdatedEvent, LinkPeerChangedEvent
 from aiohomematic.const import (
     ADDRESS_SEPARATOR,
     CLICK_EVENTS,
@@ -70,6 +70,23 @@ from aiohomematic.const import (
 )
 from aiohomematic.decorators import inspector
 from aiohomematic.exceptions import AioHomematicException, BaseHomematicException
+from aiohomematic.interfaces import (
+    CentralInfo,
+    ChannelLookup,
+    ClientProvider,
+    ConfigProvider,
+    DataCacheProvider,
+    DataPointProvider,
+    DeviceDataRefresher,
+    DeviceDescriptionProvider,
+    DeviceDetailsProvider,
+    EventBusProvider,
+    EventSubscriptionManager,
+    FileOperations,
+    ParameterVisibilityProvider,
+    ParamsetDescriptionProvider,
+    TaskScheduler,
+)
 from aiohomematic.model import week_profile as wp
 from aiohomematic.model.calculated import CalculatedDataPoint
 from aiohomematic.model.custom import data_point as hmce, definition as hmed
@@ -112,13 +129,22 @@ class Device(LogContextMixin, PayloadMixin):
     __slots__ = (
         "_address",
         "_cached_relevant_for_central_link_management",
-        "_central",
+        "_central_info",
         "_channel_group",
+        "_channel_lookup",
         "_channels",
         "_client",
+        "_client_provider",
+        "_config_provider",
+        "_data_cache_provider",
+        "_data_point_provider",
         "_description",
-        "_device_updated_callbacks",
-        "_firmware_update_callbacks",
+        "_device_data_refresher",
+        "_device_description_provider",
+        "_device_details_provider",
+        "_event_bus_provider",
+        "_event_subscription_manager",
+        "_file_operations",
         "_forced_availability",
         "_group_channels",
         "_has_custom_data_point_definition",
@@ -132,27 +158,64 @@ class Device(LogContextMixin, PayloadMixin):
         "_model",
         "_modified_at",
         "_name",
+        "_parameter_visibility_provider",
+        "_paramset_description_provider",
         "_product_group",
         "_rooms",
         "_rx_modes",
         "_sub_model",
+        "_task_scheduler",
         "_update_data_point",
         "_value_cache",
         "_week_profile",
     )
 
-    def __init__(self, *, central: hmcu.CentralUnit, interface_id: str, device_address: str) -> None:
+    def __init__(
+        self,
+        *,
+        interface_id: str,
+        device_address: str,
+        central_info: CentralInfo,
+        channel_lookup: ChannelLookup,
+        client_provider: ClientProvider,
+        config_provider: ConfigProvider,
+        data_cache_provider: DataCacheProvider,
+        data_point_provider: DataPointProvider,
+        device_data_refresher: DeviceDataRefresher,
+        device_description_provider: DeviceDescriptionProvider,
+        device_details_provider: DeviceDetailsProvider,
+        event_bus_provider: EventBusProvider,
+        event_subscription_manager: EventSubscriptionManager,
+        file_operations: FileOperations,
+        parameter_visibility_provider: ParameterVisibilityProvider,
+        paramset_description_provider: ParamsetDescriptionProvider,
+        task_scheduler: TaskScheduler,
+    ) -> None:
         """Initialize the device object."""
         PayloadMixin.__init__(self)
-        self._central: Final = central
         self._interface_id: Final = interface_id
         self._address: Final = device_address
+        self._device_details_provider: Final = device_details_provider
+        self._device_description_provider: Final = device_description_provider
+        self._paramset_description_provider: Final = paramset_description_provider
+        self._parameter_visibility_provider: Final = parameter_visibility_provider
+        self._client_provider: Final = client_provider
+        self._config_provider: Final = config_provider
+        self._central_info: Final = central_info
+        self._event_bus_provider: Final = event_bus_provider
+        self._task_scheduler: Final = task_scheduler
+        self._file_operations: Final = file_operations
+        self._device_data_refresher: Final = device_data_refresher
+        self._data_cache_provider: Final = data_cache_provider
+        self._data_point_provider: Final = data_point_provider
+        self._channel_lookup: Final = channel_lookup
+        self._event_subscription_manager: Final = event_subscription_manager
         self._channel_group: Final[dict[int | None, int]] = {}
         self._group_channels: Final[dict[int, set[int | None]]] = {}
-        self._id: Final = self._central.device_details.get_address_id(address=device_address)
-        self._interface: Final = central.device_details.get_interface(address=device_address)
-        self._client: Final = central.get_client(interface_id=interface_id)
-        self._description = self._central.device_descriptions.get_device_description(
+        self._id: Final = device_details_provider.get_address_id(address=device_address)
+        self._interface: Final = device_details_provider.get_interface(address=device_address)
+        self._client: Final = client_provider.get_client(interface_id=interface_id)
+        self._description = self._device_description_provider.get_device_description(
             interface_id=interface_id, address=device_address
         )
         _LOGGER.debug(
@@ -163,24 +226,22 @@ class Device(LogContextMixin, PayloadMixin):
 
         self._modified_at: datetime = INIT_DATETIME
         self._forced_availability: ForcedDeviceAvailability = ForcedDeviceAvailability.NOT_SET
-        self._device_updated_callbacks: Final[list[DeviceUpdatedCallback]] = []
-        self._firmware_update_callbacks: Final[list[FirmwareUpdateCallback]] = []
         self._model: Final[str] = self._description["TYPE"]
         self._ignore_on_initial_load: Final[bool] = check_ignore_model_on_initial_load(model=self._model)
         self._is_updatable: Final = self._description.get("UPDATABLE") or False
         self._rx_modes: Final = get_rx_modes(mode=self._description.get("RX_MODE", 0))
         self._sub_model: Final[str | None] = self._description.get("SUBTYPE")
-        self._ignore_for_custom_data_point: Final[bool] = central.parameter_visibility.model_is_ignored(
+        self._ignore_for_custom_data_point: Final[bool] = parameter_visibility_provider.model_is_ignored(
             model=self._model
         )
         self._manufacturer = self._identify_manufacturer()
-        self._product_group: Final = self._client.get_product_group(model=self._model)
+        self._product_group: Final[ProductGroup] = self._client.get_product_group(model=self._model)
         # marker if device will be created as custom data_point
         self._has_custom_data_point_definition: Final = (
             hmed.data_point_definition_exists(model=self._model) and not self._ignore_for_custom_data_point
         )
         self._name: Final = get_device_name(
-            central=central,
+            device_details_provider=device_details_provider,
             device_address=device_address,
             model=self._model,
         )
@@ -191,7 +252,7 @@ class Device(LogContextMixin, PayloadMixin):
             address: Channel(device=self, channel_address=address) for address in channel_addresses
         }
         self._value_cache: Final[_ValueCache] = _ValueCache(device=self)
-        self._rooms: Final = central.device_details.get_device_rooms(device_address=device_address)
+        self._rooms: Final = device_details_provider.get_device_rooms(device_address=device_address)
         self._update_data_point: Final = DpUpdate(device=self) if self.is_updatable else None
         self._week_profile: wp.WeekProfile[dict[Any, Any]] | None = None
         _LOGGER.debug(
@@ -263,9 +324,14 @@ class Device(LogContextMixin, PayloadMixin):
         return tuple(data_points)
 
     @property
-    def central(self) -> hmcu.CentralUnit:
-        """Return the central of the device."""
-        return self._central
+    def central_info(self) -> CentralInfo:
+        """Return the central info of the device."""
+        return self._central_info
+
+    @property
+    def channel_lookup(self) -> ChannelLookup:
+        """Return the channel lookup provider."""
+        return self._channel_lookup
 
     @property
     def channels(self) -> Mapping[str, Channel]:
@@ -284,6 +350,11 @@ class Device(LogContextMixin, PayloadMixin):
             return self._dp_config_pending.value is True
         return False
 
+    @property
+    def config_provider(self) -> ConfigProvider:
+        """Return the config provider."""
+        return self._config_provider
+
     @property
     def custom_data_points(self) -> tuple[hmce.CustomDataPoint, ...]:
         """Return the custom data points."""
@@ -291,6 +362,16 @@ class Device(LogContextMixin, PayloadMixin):
             channel.custom_data_point for channel in self._channels.values() if channel.custom_data_point is not None
         )
 
+    @property
+    def data_cache_provider(self) -> DataCacheProvider:
+        """Return the DataCacheProvider of the device."""
+        return self._data_cache_provider
+
+    @property
+    def data_point_provider(self) -> DataPointProvider:
+        """Return the data point provider."""
+        return self._data_point_provider
+
     @property
     def default_schedule_channel(self) -> Channel | None:
         """Return the schedule channel address."""
@@ -299,6 +380,31 @@ class Device(LogContextMixin, PayloadMixin):
                 return channel
         return None
 
+    @property
+    def device_data_refresher(self) -> DeviceDataRefresher:
+        """Return the device data refresher."""
+        return self._device_data_refresher
+
+    @property
+    def device_description_provider(self) -> DeviceDescriptionProvider:
+        """Return the device description provider."""
+        return self._device_description_provider
+
+    @property
+    def device_details_provider(self) -> DeviceDetailsProvider:
+        """Return the device details provider."""
+        return self._device_details_provider
+
+    @property
+    def event_bus_provider(self) -> EventBusProvider:
+        """Return the EventBusProvider of the device."""
+        return self._event_bus_provider
+
+    @property
+    def event_subscription_manager(self) -> EventSubscriptionManager:
+        """Return the event subscription manager."""
+        return self._event_subscription_manager
+
     @property
     def firmware_updatable(self) -> bool:
         """Return the firmware update state of the device."""
@@ -365,7 +471,7 @@ class Device(LogContextMixin, PayloadMixin):
     def info(self) -> Mapping[str, Any]:
         """Return the device info."""
         device_info = dict(self.info_payload)
-        device_info["central"] = self._central.info_payload
+        device_info["central"] = self._central_info.info_payload
         return device_info
 
     @property
@@ -385,6 +491,16 @@ class Device(LogContextMixin, PayloadMixin):
             channel: channel.link_peer_channels for channel in self._channels.values() if channel.link_peer_channels
         }
 
+    @property
+    def parameter_visibility_provider(self) -> ParameterVisibilityProvider:
+        """Return the parameter visibility provider."""
+        return self._parameter_visibility_provider
+
+    @property
+    def paramset_description_provider(self) -> ParamsetDescriptionProvider:
+        """Return the paramset description provider."""
+        return self._paramset_description_provider
+
     @property
     def product_group(self) -> ProductGroup:
         """Return the product group of the device."""
@@ -412,6 +528,11 @@ class Device(LogContextMixin, PayloadMixin):
             return False
         return self._week_profile.supports_schedule
 
+    @property
+    def task_scheduler(self) -> TaskScheduler:
+        """Return the task scheduler."""
+        return self._task_scheduler
+
     @property
     def update_data_point(self) -> DpUpdate | None:
         """Return the device firmware update data_point of the device."""
@@ -512,11 +633,20 @@ class Device(LogContextMixin, PayloadMixin):
     def emit_device_updated_callback(self) -> None:
         """Do what is needed when the state of the device has been updated."""
         self._set_modified_at()
-        for callback_handler in self._device_updated_callbacks:
-            try:
-                callback_handler()
-            except Exception as exc:
-                _LOGGER.error("EMIT_DEVICE_UPDATED failed: %s", extract_exc_args(exc=exc))  # i18n-log: ignore
+
+        # Publish to EventBus asynchronously
+        async def _publish_device_updated() -> None:
+            await self._event_bus_provider.event_bus.publish(
+                event=DeviceUpdatedEvent(
+                    timestamp=datetime.now(),
+                    device_address=self._address,
+                )
+            )
+
+        self._task_scheduler.create_task(
+            target=_publish_device_updated,
+            name=f"device-updated-{self._address}",
+        )
 
     @inspector
     async def export_device_definition(self) -> None:
@@ -660,7 +790,7 @@ class Device(LogContextMixin, PayloadMixin):
         if self._week_profile:
             await self._week_profile.reload_and_cache_schedule()
 
-        await self._central.save_files(save_paramset_descriptions=True)
+        await self._file_operations.save_files(save_paramset_descriptions=True)
         self.emit_device_updated_callback()
 
     def refresh_firmware_data(self) -> None:
@@ -670,7 +800,7 @@ class Device(LogContextMixin, PayloadMixin):
         old_firmware_update_state = self.firmware_update_state
         old_firmware_updatable = self.firmware_updatable
 
-        self._description = self._central.device_descriptions.get_device_description(
+        self._description = self._device_description_provider.get_device_description(
             interface_id=self._interface_id, address=self._address
         )
 
@@ -680,22 +810,45 @@ class Device(LogContextMixin, PayloadMixin):
             or old_firmware_update_state != self.firmware_update_state
             or old_firmware_updatable != self.firmware_updatable
         ):
-            for callback_handler in self._firmware_update_callbacks:
-                callback_handler()
+            # Publish to EventBus asynchronously
+            async def _publish_firmware_updated() -> None:
+                await self._event_bus_provider.event_bus.publish(
+                    event=FirmwareUpdatedEvent(
+                        timestamp=datetime.now(),
+                        device_address=self._address,
+                    )
+                )
+
+            self._task_scheduler.create_task(
+                target=_publish_firmware_updated,
+                name=f"firmware-updated-{self._address}",
+            )
 
     def register_device_updated_callback(self, *, cb: DeviceUpdatedCallback) -> UnregisterCallback:
         """Register update callback."""
-        if callable(cb) and cb not in self._device_updated_callbacks:
-            self._device_updated_callbacks.append(cb)
-            return partial(self.unregister_device_updated_callback, cb=cb)
-        return None
+
+        # Create adapter that filters for this device's events
+        def event_handler(event: DeviceUpdatedEvent) -> None:
+            if event.device_address == self._address:
+                cb()
+
+        return self._event_bus_provider.event_bus.subscribe(
+            event_type=DeviceUpdatedEvent,
+            handler=event_handler,
+        )
 
     def register_firmware_update_callback(self, *, cb: FirmwareUpdateCallback) -> UnregisterCallback:
         """Register firmware update callback."""
-        if callable(cb) and cb not in self._firmware_update_callbacks:
-            self._firmware_update_callbacks.append(cb)
-            return partial(self.unregister_firmware_update_callback, cb=cb)
-        return None
+
+        # Create adapter that filters for this device's events
+        def event_handler(event: FirmwareUpdatedEvent) -> None:
+            if event.device_address == self._address:
+                cb()
+
+        return self._event_bus_provider.event_bus.subscribe(
+            event_type=FirmwareUpdatedEvent,
+            handler=event_handler,
+        )
 
     def remove(self) -> None:
         """Remove data points from collections and central."""
@@ -716,16 +869,6 @@ class Device(LogContextMixin, PayloadMixin):
             for dp in self.generic_data_points:
                 dp.emit_data_point_updated_event()
 
-    def unregister_device_updated_callback(self, *, cb: DeviceUpdatedCallback) -> None:
-        """Remove update callback."""
-        if cb in self._device_updated_callbacks:
-            self._device_updated_callbacks.remove(cb)
-
-    def unregister_firmware_update_callback(self, *, cb: FirmwareUpdateCallback) -> None:
-        """Remove firmware update callback."""
-        if cb in self._firmware_update_callbacks:
-            self._firmware_update_callbacks.remove(cb)
-
     @inspector
     async def update_firmware(self, *, refresh_after_update_intervals: tuple[int, ...]) -> bool:
         """Update the firmware of the Homematic device."""
@@ -734,10 +877,10 @@ class Device(LogContextMixin, PayloadMixin):
         async def refresh_data() -> None:
             for refresh_interval in refresh_after_update_intervals:
                 await asyncio.sleep(refresh_interval)
-                await self._central.refresh_firmware_data(device_address=self._address)
+                await self._device_data_refresher.refresh_firmware_data(device_address=self._address)
 
         if refresh_after_update_intervals:
-            self._central.looper.create_task(target=refresh_data, name="refresh_firmware_data")
+            self._task_scheduler.create_task(target=refresh_data, name="refresh_firmware_data")
 
         return update_result
 
@@ -759,7 +902,6 @@ class Channel(LogContextMixin, PayloadMixin):
     __slots__ = (
         "_address",
         "_calculated_data_points",
-        "_central",
         "_custom_data_point",
         "_description",
         "_device",
@@ -772,7 +914,6 @@ class Channel(LogContextMixin, PayloadMixin):
         "_is_in_multi_group",
         "_is_schedule_channel",
         "_link_peer_addresses",
-        "_link_peer_changed_callbacks",
         "_link_source_categories",
         "_link_source_roles",
         "_link_target_categories",
@@ -791,19 +932,20 @@ class Channel(LogContextMixin, PayloadMixin):
         PayloadMixin.__init__(self)
 
         self._device: Final = device
-        self._central: Final = device.central
         self._address: Final = channel_address
-        self._id: Final = self._central.device_details.get_address_id(address=channel_address)
+        self._id: Final = self._device.device_details_provider.get_address_id(address=channel_address)
         self._no: Final[int | None] = get_channel_no(address=channel_address)
         self._name_data: Final = get_channel_name_data(channel=self)
-        self._description: DeviceDescription = self._central.device_descriptions.get_device_description(
+        self._description: DeviceDescription = self._device.device_description_provider.get_device_description(
             interface_id=self._device.interface_id, address=channel_address
         )
         self._type_name: Final[str] = self._description["TYPE"]
         self._is_schedule_channel: Final[bool] = WEEK_PROFILE_PATTERN.match(self._type_name) is not None
         self._paramset_keys: Final = tuple(ParamsetKey(paramset_key) for paramset_key in self._description["PARAMSETS"])
 
-        self._unique_id: Final = generate_channel_unique_id(central=self._central, address=channel_address)
+        self._unique_id: Final = generate_channel_unique_id(
+            config_provider=self._device.config_provider, address=channel_address
+        )
         self._group_no: int | None = None
         self._group_master: Channel | None = None
         self._is_in_multi_group: bool | None = None
@@ -812,7 +954,6 @@ class Channel(LogContextMixin, PayloadMixin):
         self._generic_data_points: Final[dict[DataPointKey, GenericDataPointAny]] = {}
         self._generic_events: Final[dict[DataPointKey, GenericEvent]] = {}
         self._link_peer_addresses: tuple[str, ...] = ()
-        self._link_peer_changed_callbacks: list[LinkPeerChangedCallback] = []
         self._link_source_roles: tuple[str, ...] = (
             tuple(source_roles.split(" ")) if (source_roles := self._description.get("LINK_SOURCE_ROLES")) else ()
         )
@@ -826,8 +967,8 @@ class Channel(LogContextMixin, PayloadMixin):
             target_roles=self._link_target_roles, channel_type_name=self._type_name
         )
         self._modified_at: datetime = INIT_DATETIME
-        self._rooms: Final = self._central.device_details.get_channel_rooms(channel_address=channel_address)
-        self._function: Final = self._central.device_details.get_function_text(address=self._address)
+        self._rooms: Final = self._device.device_details_provider.get_channel_rooms(channel_address=channel_address)
+        self._function: Final = self._device.device_details_provider.get_function_text(address=self._address)
         self.init_channel()
 
     def __str__(self) -> str:
@@ -851,11 +992,6 @@ class Channel(LogContextMixin, PayloadMixin):
         """Return the generic data points."""
         return tuple(self._calculated_data_points.values())
 
-    @property
-    def central(self) -> hmcu.CentralUnit:
-        """Return the central."""
-        return self._central
-
     @property
     def custom_data_point(self) -> hmce.CustomDataPoint | None:
         """Return the custom data point."""
@@ -939,7 +1075,8 @@ class Channel(LogContextMixin, PayloadMixin):
         return tuple(
             channel
             for address in self._link_peer_addresses
-            if self._link_peer_addresses and (channel := self._central.get_channel(channel_address=address)) is not None
+            if self._link_peer_addresses
+            and (channel := self._device.channel_lookup.get_channel(channel_address=address)) is not None
         )
 
     @property
@@ -974,7 +1111,7 @@ class Channel(LogContextMixin, PayloadMixin):
     @property
     def paramset_descriptions(self) -> Mapping[ParamsetKey, Mapping[str, ParameterData]]:
         """Return the paramset descriptions of the channel."""
-        return self._central.paramset_descriptions.get_channel_paramset_descriptions(
+        return self._device.paramset_description_provider.get_channel_paramset_descriptions(
             interface_id=self._device.interface_id, channel_address=self._address
         )
 
@@ -1027,12 +1164,11 @@ class Channel(LogContextMixin, PayloadMixin):
     def add_data_point(self, *, data_point: CallbackDataPoint) -> None:
         """Add a data_point to a channel."""
         if isinstance(data_point, BaseParameterDataPoint):
-            self._central.add_event_subscription(data_point=data_point)
+            self._device.event_subscription_manager.add_event_subscription(data_point=data_point)
         if isinstance(data_point, CalculatedDataPoint):
             self._calculated_data_points[data_point.dpk] = data_point
         if isinstance(data_point, GenericDataPoint):
             self._generic_data_points[data_point.dpk] = data_point
-            self._device.register_device_updated_callback(cb=data_point.emit_data_point_updated_event)
         if isinstance(data_point, hmce.CustomDataPoint):
             self._custom_data_point = data_point
         if isinstance(data_point, GenericEvent):
@@ -1059,11 +1195,20 @@ class Channel(LogContextMixin, PayloadMixin):
     @loop_check
     def emit_link_peer_changed_event(self) -> None:
         """Do what is needed when the link peer has been changed for the device."""
-        for callback_handler in self._link_peer_changed_callbacks:
-            try:
-                callback_handler()
-            except Exception as exc:
-                _LOGGER.error("EMIT_LINK_PEER_CHANGED_EVENT failed: %s", extract_exc_args(exc=exc))  # i18n-log: ignore
+
+        # Publish to EventBus asynchronously
+        async def _publish_link_peer_changed() -> None:
+            await self._device.event_bus_provider.event_bus.publish(
+                event=LinkPeerChangedEvent(
+                    timestamp=datetime.now(),
+                    channel_address=self._address,
+                )
+            )
+
+        self._device.task_scheduler.create_task(
+            target=_publish_link_peer_changed,
+            name=f"link-peer-changed-{self._address}",
+        )
 
     async def finalize_init(self) -> None:
         """Finalize the channel init action after model setup."""
@@ -1177,7 +1322,7 @@ class Channel(LogContextMixin, PayloadMixin):
 
     def init_channel(self) -> None:
         """Init the channel."""
-        self._central.looper.create_task(target=self.init_link_peer(), name=f"init_channel_{self._address}")
+        self._device.task_scheduler.create_task(target=self.init_link_peer(), name=f"init_channel_{self._address}")
 
     async def init_link_peer(self) -> None:
         """Init the link partners."""
@@ -1217,10 +1362,16 @@ class Channel(LogContextMixin, PayloadMixin):
 
     def register_link_peer_changed_callback(self, *, cb: LinkPeerChangedCallback) -> UnregisterCallback:
         """Register the link peer changed callback."""
-        if callable(cb) and cb not in self._link_peer_changed_callbacks:
-            self._link_peer_changed_callbacks.append(cb)
-            return partial(self._unregister_link_peer_changed_callback, cb=cb)
-        return None
+
+        # Create adapter that filters for this channel's events
+        def event_handler(event: LinkPeerChangedEvent) -> None:
+            if event.channel_address == self._address:
+                cb()
+
+        return self._device.event_bus_provider.event_bus.subscribe(
+            event_type=LinkPeerChangedEvent,
+            handler=event_handler,
+        )
 
     def remove(self) -> None:
         """Remove data points from collections and central."""
@@ -1281,12 +1432,11 @@ class Channel(LogContextMixin, PayloadMixin):
     def _remove_data_point(self, *, data_point: CallbackDataPoint) -> None:
         """Remove a data_point from a channel."""
         if isinstance(data_point, BaseParameterDataPoint):
-            self._central.remove_event_subscription(data_point=data_point)
+            self._device.event_subscription_manager.remove_event_subscription(data_point=data_point)
         if isinstance(data_point, CalculatedDataPoint):
             del self._calculated_data_points[data_point.dpk]
         if isinstance(data_point, GenericDataPoint):
             del self._generic_data_points[data_point.dpk]
-            self._device.unregister_device_updated_callback(cb=data_point.emit_data_point_updated_event)
         if isinstance(data_point, hmce.CustomDataPoint):
             self._custom_data_point = None
         if isinstance(data_point, GenericEvent):
@@ -1296,11 +1446,6 @@ class Channel(LogContextMixin, PayloadMixin):
     def _set_modified_at(self) -> None:
         self._modified_at = datetime.now()
 
-    def _unregister_link_peer_changed_callback(self, *, cb: LinkPeerChangedCallback) -> None:
-        """Unregister the link peer changed callback."""
-        if cb in self._link_peer_changed_callbacks:
-            self._link_peer_changed_callbacks.remove(cb)
-
 
 class _ValueCache:
     """A Cache to temporarily stored values."""
@@ -1420,7 +1565,7 @@ class _ValueCache:
         if (
             dpk.paramset_key == ParamsetKey.VALUES
             and (
-                global_value := self._device.central.data_cache.get_data(
+                global_value := self._device.data_cache_provider.get_data(
                     interface=self._device.interface,
                     channel_address=dpk.channel_address,
                     parameter=dpk.parameter,
@@ -1459,19 +1604,23 @@ class _DefinitionExporter:
     """Export device definitions from cache."""
 
     __slots__ = (
-        "_central",
         "_client",
+        "_config_provider",
         "_device_address",
+        "_device_description_provider",
         "_interface_id",
         "_random_id",
         "_storage_directory",
+        "_task_scheduler",
     )
 
     def __init__(self, *, device: Device) -> None:
         """Init the device exporter."""
         self._client: Final = device.client
-        self._central: Final = device.client.central
-        self._storage_directory: Final = self._central.config.storage_directory
+        self._config_provider: Final = device.config_provider
+        self._device_description_provider: Final = device.device_description_provider
+        self._task_scheduler: Final = device.task_scheduler
+        self._storage_directory: Final = self._config_provider.config.storage_directory
         self._interface_id: Final = device.interface_id
         self._device_address: Final = device.address
         self._random_id: Final[str] = f"VCU{int(random.randint(1000000, 9999999))}"
@@ -1480,7 +1629,7 @@ class _DefinitionExporter:
     async def export_data(self) -> None:
         """Export data."""
         device_descriptions: Mapping[str, DeviceDescription] = (
-            self._central.device_descriptions.get_device_with_channels(
+            self._device_description_provider.get_device_with_channels(
                 interface_id=self._interface_id, device_address=self._device_address
             )
         )
@@ -1537,4 +1686,7 @@ class _DefinitionExporter:
                 fptr.write(orjson.dumps(data, option=orjson.OPT_INDENT_2 | orjson.OPT_NON_STR_KEYS))
             return DataOperationResult.SAVE_SUCCESS
 
-        return await self._central.looper.async_add_executor_job(perform_save, name="save-device-description")
+        return cast(
+            DataOperationResult,
+            await self._task_scheduler.async_add_executor_job(perform_save, name="save-device-description"),
+        )
