@@ -75,7 +75,7 @@ class GenericDataPoint[ParameterT: ParamType, InputParameterT: ParamType](
             Parameter.STICKY_UN_REACH,
         ):
             self._device.emit_device_updated_callback()
-            self._central.emit_homematic_callback(
+            self._event_emitter.emit_homematic_callback(
                 event_type=EventType.DEVICE_AVAILABILITY,
                 event_data=self.get_event_data(value=new_value),
             )
@@ -103,7 +103,7 @@ class GenericDataPoint[ParameterT: ParamType, InputParameterT: ParamType](
         do_validate: bool = True,
     ) -> set[DP_KEY_VALUE]:
         """Send value to ccu, or use collector if set."""
-        if not self.is_writeable:
+        if not self.is_writable:
             _LOGGER.error(
                 i18n.tr(
                     "log.model.generic_data_point.send_value.not_writable",
@@ -145,7 +145,7 @@ class GenericDataPoint[ParameterT: ParamType, InputParameterT: ParamType](
         """Generate the usage for the data_point."""
         if self._forced_usage:
             return self._forced_usage
-        if self._central.parameter_visibility.parameter_is_hidden(
+        if self._visibility_provider.parameter_is_hidden(
             channel=self._channel,
             paramset_key=self._paramset_key,
             parameter=self._parameter,
