@@ -42,13 +42,13 @@ from datetime import UTC, datetime
 import json
 import logging
 import os
-from typing import Any, Final, Self
+from typing import Any, Final, Self, cast
 import zipfile
 
 import orjson
 from slugify import slugify
 
-from aiohomematic import central as hmcu, i18n
+from aiohomematic import i18n
 from aiohomematic.async_support import loop_check
 from aiohomematic.const import (
     ADDRESS_SEPARATOR,
@@ -66,6 +66,14 @@ from aiohomematic.const import (
     ParamsetKey,
     RPCType,
 )
+from aiohomematic.interfaces import (
+    CentralInfo,
+    ConfigProvider,
+    DeviceDescriptionProvider,
+    DeviceProvider,
+    ParamsetDescriptionProvider,
+    TaskScheduler,
+)
 from aiohomematic.model.device import Device
 from aiohomematic.support import (
     check_or_create_directory,
@@ -85,12 +93,15 @@ class BasePersistentFile(ABC):
     """Cache for files."""
 
     __slots__ = (
-        "_central",
+        "_central_info",
+        "_config_provider",
+        "_device_provider",
         "_directory",
         "_file_postfix",
         "_persistent_content",
         "_save_load_semaphore",
         "_sub_directory",
+        "_task_scheduler",
         "_use_ts_in_file_names",
         "last_hash_saved",
         "last_save_triggered",
@@ -102,15 +113,21 @@ class BasePersistentFile(ABC):
     def __init__(
         self,
         *,
-        central: hmcu.CentralUnit,
+        central_info: CentralInfo,
+        config_provider: ConfigProvider,
+        device_provider: DeviceProvider,
+        task_scheduler: TaskScheduler,
         persistent_content: dict[str, Any],
     ) -> None:
         """Initialize the base class of the persistent content."""
         self._save_load_semaphore: Final = asyncio.Semaphore()
-        self._central: Final = central
+        self._config_provider: Final = config_provider
+        self._task_scheduler: Final = task_scheduler
+        self._central_info: Final = central_info
+        self._device_provider: Final = device_provider
         self._persistent_content: Final = persistent_content
         self._directory: Final = _get_file_path(
-            storage_directory=central.config.storage_directory, sub_directory=self._sub_directory
+            storage_directory=config_provider.config.storage_directory, sub_directory=self._sub_directory
         )
         self.last_save_triggered: datetime = INIT_DATETIME
         self.last_hash_saved = hash_sha256(value=persistent_content)
@@ -121,7 +138,7 @@ class BasePersistentFile(ABC):
         self.last_save_triggered = datetime.now()
         return (
             check_or_create_directory(directory=self._directory)
-            and self._central.config.use_caches
+            and self._config_provider.config.use_caches
             and self.content_hash != self.last_hash_saved
         )
 
@@ -139,11 +156,11 @@ class BasePersistentFile(ABC):
         """Remove stored file from disk."""
 
         def _perform_clear() -> None:
-            delete_file(directory=self._directory, file_name=f"{self._central.name}*.json".lower())
+            delete_file(directory=self._directory, file_name=f"{self._central_info.name}*.json".lower())
             self._persistent_content.clear()
 
         async with self._save_load_semaphore:
-            await self._central.looper.async_add_executor_job(_perform_clear, name="clear-persistent-content")
+            await self._task_scheduler.async_add_executor_job(_perform_clear, name="clear-persistent-content")
 
     async def load(self, *, file_path: str | None = None) -> DataOperationResult:
         """
@@ -182,8 +199,9 @@ class BasePersistentFile(ABC):
             return DataOperationResult.LOAD_SUCCESS
 
         async with self._save_load_semaphore:
-            return await self._central.looper.async_add_executor_job(
-                _perform_load, name=f"load-persistent-content-{self._get_file_name()}"
+            return cast(
+                DataOperationResult,
+                await self._task_scheduler.async_add_executor_job(_perform_load, name="load-persistent-content"),
             )
 
     async def save(self, *, randomize_output: bool = False, use_ts_in_file_name: bool = False) -> DataOperationResult:
@@ -215,8 +233,9 @@ class BasePersistentFile(ABC):
             return DataOperationResult.SAVE_SUCCESS
 
         async with self._save_load_semaphore:
-            return await self._central.looper.async_add_executor_job(
-                _perform_save, name=f"save-persistent-content-{self._get_file_name()}"
+            return cast(
+                DataOperationResult,
+                await self._task_scheduler.async_add_executor_job(_perform_save, name="save-persistent-content"),
             )
 
     def _get_file_name(
@@ -226,7 +245,7 @@ class BasePersistentFile(ABC):
     ) -> str:
         """Return the file name."""
         return _get_file_name(
-            central_name=self._central.name,
+            central_name=self._central_info.name,
             file_name=self._file_postfix,
             ts=datetime.now() if use_ts_in_file_name else None,
         )
@@ -244,14 +263,14 @@ class BasePersistentFile(ABC):
         if not randomize_output:
             return content
 
-        addresses = [device.address for device in self._central.devices]
+        addresses = [device.address for device in self._device_provider.devices]
         text = content.decode(encoding=UTF_8)
         for device_address, rnd_address in create_random_device_addresses(addresses=addresses).items():
             text = text.replace(device_address, rnd_address)
         return text.encode(encoding=UTF_8)
 
 
-class DeviceDescriptionCache(BasePersistentFile):
+class DeviceDescriptionCache(BasePersistentFile, DeviceDescriptionProvider):
     """Cache for device/channel names."""
 
     __slots__ = (
@@ -263,12 +282,22 @@ class DeviceDescriptionCache(BasePersistentFile):
     _file_postfix = FILE_DEVICES
     _sub_directory = SUB_DIRECTORY_CACHE
 
-    def __init__(self, *, central: hmcu.CentralUnit) -> None:
+    def __init__(
+        self,
+        *,
+        central_info: CentralInfo,
+        config_provider: ConfigProvider,
+        device_provider: DeviceProvider,
+        task_scheduler: TaskScheduler,
+    ) -> None:
         """Initialize the device description cache."""
         # {interface_id, [device_descriptions]}
         self._raw_device_descriptions: Final[dict[str, list[DeviceDescription]]] = defaultdict(list)
         super().__init__(
-            central=central,
+            central_info=central_info,
+            config_provider=config_provider,
+            device_provider=device_provider,
+            task_scheduler=task_scheduler,
             persistent_content=self._raw_device_descriptions,
         )
         # {interface_id, {device_address, [channel_address]}}
@@ -342,8 +371,8 @@ class DeviceDescriptionCache(BasePersistentFile):
 
     async def load(self, *, file_path: str | None = None) -> DataOperationResult:
         """Load device data from disk into _device_description_cache."""
-        if not self._central.config.use_caches:
-            _LOGGER.debug("load: not caching paramset descriptions for %s", self._central.name)
+        if not self._config_provider.config.use_caches:
+            _LOGGER.debug("load: not caching paramset descriptions for %s", self._central_info.name)
             return DataOperationResult.NO_LOAD
         if (result := await super().load(file_path=file_path)) == DataOperationResult.LOAD_SUCCESS:
             for (
@@ -392,7 +421,7 @@ class DeviceDescriptionCache(BasePersistentFile):
             desc_map.pop(address, None)
 
 
-class ParamsetDescriptionCache(BasePersistentFile):
+class ParamsetDescriptionCache(BasePersistentFile, ParamsetDescriptionProvider):
     """Cache for paramset descriptions."""
 
     __slots__ = (
@@ -403,14 +432,24 @@ class ParamsetDescriptionCache(BasePersistentFile):
     _file_postfix = FILE_PARAMSETS
     _sub_directory = SUB_DIRECTORY_CACHE
 
-    def __init__(self, *, central: hmcu.CentralUnit) -> None:
+    def __init__(
+        self,
+        *,
+        config_provider: ConfigProvider,
+        task_scheduler: TaskScheduler,
+        central_info: CentralInfo,
+        device_provider: DeviceProvider,
+    ) -> None:
         """Init the paramset description cache."""
         # {interface_id, {channel_address, paramsets}}
         self._raw_paramset_descriptions: Final[dict[str, dict[str, dict[ParamsetKey, dict[str, ParameterData]]]]] = (
             defaultdict(lambda: defaultdict(lambda: defaultdict(dict)))
         )
         super().__init__(
-            central=central,
+            config_provider=config_provider,
+            task_scheduler=task_scheduler,
+            central_info=central_info,
+            device_provider=device_provider,
             persistent_content=self._raw_paramset_descriptions,
         )
 
@@ -490,8 +529,8 @@ class ParamsetDescriptionCache(BasePersistentFile):
 
     async def load(self, *, file_path: str | None = None) -> DataOperationResult:
         """Load paramset descriptions from disk into paramset cache."""
-        if not self._central.config.use_caches:
-            _LOGGER.debug("load: not caching device descriptions for %s", self._central.name)
+        if not self._config_provider.config.use_caches:
+            _LOGGER.debug("load: not caching device descriptions for %s", self._central_info.name)
             return DataOperationResult.NO_LOAD
         if (result := await super().load(file_path=file_path)) == DataOperationResult.LOAD_SUCCESS:
             self._init_address_parameter_list()
@@ -539,10 +578,10 @@ class SessionRecorder(BasePersistentFile):
 
     __slots__ = (
         "_active",
-        "_ttl",
         "_is_recording",
         "_refresh_on_get",
         "_store",
+        "_ttl",
     )
 
     _file_postfix = FILE_SESSION_RECORDER
@@ -551,7 +590,10 @@ class SessionRecorder(BasePersistentFile):
     def __init__(
         self,
         *,
-        central: hmcu.CentralUnit,
+        central_info: CentralInfo,
+        config_provider: ConfigProvider,
+        device_provider: DeviceProvider,
+        task_scheduler: TaskScheduler,
         active: bool,
         ttl_seconds: float,
         refresh_on_get: bool = False,
@@ -569,7 +611,10 @@ class SessionRecorder(BasePersistentFile):
             lambda: defaultdict(lambda: defaultdict(dict))
         )
         super().__init__(
-            central=central,
+            config_provider=config_provider,
+            task_scheduler=task_scheduler,
+            central_info=central_info,
+            device_provider=device_provider,
             persistent_content=self._store,
         )
 
@@ -599,14 +644,14 @@ class SessionRecorder(BasePersistentFile):
         self._store.clear()
         self._active = True
         if on_time > 0:
-            self._central.looper.create_task(
+            self._task_scheduler.create_task(
                 target=self._deactivate_after_delay(
                     delay=on_time,
                     auto_save=auto_save,
                     randomize_output=randomize_output,
                     use_ts_in_file_name=use_ts_in_file_name,
                 ),
-                name=f"session_recorder_{self._central.name}",
+                name=f"session_recorder_{self._central_info.name}",
             )
         return True
 
@@ -663,14 +708,14 @@ class SessionRecorder(BasePersistentFile):
             _LOGGER.info(i18n.tr("log.store.session_recorder.deactivate.already_running"))
             return False
         if delay > 0:
-            self._central.looper.create_task(
+            self._task_scheduler.create_task(
                 target=self._deactivate_after_delay(
                     delay=delay,
                     auto_save=auto_save,
                     randomize_output=randomize_output,
                     use_ts_in_file_name=use_ts_in_file_name,
                 ),
-                name=f"session_recorder_{self._central.name}",
+                name=f"session_recorder_{self._central_info.name}",
             )
         else:
             self._active = False
