@@ -10,7 +10,7 @@ from __future__ import annotations
 
 import base64
 from collections import defaultdict
-from collections.abc import Callable, Collection, Mapping
+from collections.abc import Collection, Mapping
 import contextlib
 from dataclasses import dataclass
 from datetime import datetime
@@ -26,10 +26,11 @@ import re
 import socket
 import ssl
 import sys
-from typing import Any, Final, cast
+from typing import Any, Final
 
 import orjson
 
+from aiohomematic import i18n
 from aiohomematic.const import (
     ADDRESS_SEPARATOR,
     ALLOWED_HOSTNAME_PATTERN,
@@ -109,7 +110,11 @@ def check_or_create_directory(*, directory: str) -> bool:
             os.makedirs(directory)
         except OSError as oserr:
             raise AioHomematicException(
-                f"CHECK_OR_CREATE_DIRECTORY failed: Unable to create directory {directory} ('{oserr.strerror}')"
+                i18n.tr(
+                    "exception.support.check_or_create_directory.failed",
+                    directory=directory,
+                    reason=oserr.strerror,
+                )
             ) from oserr
     return True
 
@@ -146,7 +151,7 @@ def to_bool(*, value: Any) -> bool:
         return value
 
     if not isinstance(value, str):
-        raise TypeError("invalid literal for boolean. Not a string.")
+        raise TypeError(i18n.tr("exception.support.boolean.invalid_type"))
 
     return value.lower() in ["y", "yes", "t", "true", "on", "1"]
 
@@ -156,21 +161,25 @@ def check_password(*, password: str | None) -> bool:
     if password is None:
         return False
     if CCU_PASSWORD_PATTERN.fullmatch(password) is None:
-        _LOGGER.warning(
-            "CHECK_CONFIG: password contains not allowed characters. "
-            "Use only allowed characters. See password regex: %s",
-            CCU_PASSWORD_PATTERN.pattern,
+        _LOGGER.error(
+            i18n.tr(
+                "log.support.check_password.invalid_chars",
+                pattern=CCU_PASSWORD_PATTERN.pattern,
+            )
         )
         return False
     return True
 
 
-def regular_to_default_dict_hook(origin: dict, /) -> defaultdict[Any, Any]:
+def regular_to_default_dict_hook(origin: dict[str, Any], /) -> defaultdict[Any, Any]:
     """Use defaultdict in json.loads object_hook."""
-    new_dict: Callable = lambda: defaultdict(new_dict)
-    new_instance = new_dict()
+
+    def new_dict() -> defaultdict[Any, Any]:
+        return defaultdict(new_dict)
+
+    new_instance: defaultdict[Any, Any] = new_dict()
     new_instance.update(origin)
-    return cast(defaultdict[Any, Any], new_instance)
+    return new_instance
 
 
 def _create_tls_context(*, verify_tls: bool) -> ssl.SSLContext:
@@ -268,7 +277,12 @@ def get_ip_addr(host: str, port: int, /) -> str | None:
         socket.gethostbyname(host)
     except Exception as exc:
         raise AioHomematicException(
-            f"GET_LOCAL_IP: Can't resolve host for {host}:{port}: {extract_exc_args(exc=exc)}"
+            i18n.tr(
+                "exception.support.get_local_ip.resolve_failed",
+                host=host,
+                port=port,
+                reason=extract_exc_args(exc=exc),
+            )
         ) from exc
     tmp_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
     tmp_socket.settimeout(TIMEOUT)
@@ -493,8 +507,10 @@ def _make_value_hashable(*, value: Any) -> Any:
     return value
 
 
-def get_rx_modes(*, mode: int) -> tuple[RxMode, ...]:
+def get_rx_modes(*, mode: int | None) -> tuple[RxMode, ...]:
     """Convert int to rx modes."""
+    if mode is None:
+        return ()
     rx_modes: set[RxMode] = set()
     if mode & RxMode.LAZY_CONFIG:
         mode -= RxMode.LAZY_CONFIG
